/*-----------------------------------------------------------------------------
  API.H -
 Copyright 1993-96 Comtrol Corporation.  All rights reserved.  Proprietary
 information only for development or use with Comtrol products.
|------------------------------------------------------------------------------*/
#ifdef __cplusplus
extern "C" {
#endif

typedef unsigned short WORD_T;

/*****************************************************************************/
#define TICK_PERIOD 3650               /* interrupt period in micro sec */
#define CLOSE_TBEDLY 15           /* aaClose() Tx buf empty delay in seconds */
#define RX_HIWATER RXFIFO_SIZE - 128   /* sw input flow ctl high water mark */
#define RX_LOWATER 0                   /* sw input flow ctl low water mark */
#define OFF      0
#define ON       1
#define NOCHANGE 2
#define CTRLC_INT 0x23                 /* CTRL+C interrupt number */

/* Microchannel defines */
#define MCA8CHAN    0x6359             /* 8 port POS controller ID */
#define MCA16CHAN   0x6358             /* 16 port POS controller ID */
#define MCA32CHAN   0x635A             /* 32 port POS controller ID */
#define MAXMCASLOTS  0x10              /* max number microchannel slots */


/*****************************************************************************
  Communications Parameter Flags
  Device status uses the following flags:
******************************************************************************/
/* Open type and TX and RX identifier flags (WORD_T) */
#define COM_OPEN     0x0001            /* device open */
#define COM_TX       0x0002            /* transmit */
#define COM_RX       0x0004            /* receive */

/* Flow control flags (WORD_T) */
#define COM_FLOW_NONE  0x0000
#define COM_FLOW_IS    0x0008          /* input software flow control */
#define COM_FLOW_IH    0x0010          /* input hardware flow control */
#define COM_FLOW_OS    0x0020          /* output software flow control */
#define COM_FLOW_OH    0x0040          /* output hardware flow control */
#define COM_FLOW_OXANY 0x0080          /* restart output on any Rx char */
#define COM_RXFLOW_ON  0x0100          /* Rx data flow is ON */
#define COM_TXFLOW_ON  0x0200          /* Tx data flow is ON */

/* Break flag (WORD_T) */
#define COM_BREAK_ON   0x0400          /* break signal is ON */

/* Modem control flags (unsigned char) */
#define COM_MDM_RTS   0x02             /* request to send */
#define COM_MDM_DTR   0x04             /* data terminal ready */
#define COM_MDM_CD    CD_ACT           /* carrier detect (0x08) */
#define COM_MDM_DSR   DSR_ACT          /* data set ready (0x10) */
#define COM_MDM_CTS   CTS_ACT          /* clear to send (0x20) */

/* Stop bit flags (unsigned char) */
#define COM_STOPBIT_1  0x01            /* 1 stop bit */
#define COM_STOPBIT_2  0x02            /* 2 stop bits */

/* Data bit flags (unsigned char) */
#define COM_DATABIT_7  0x01            /* 7 data bits */
#define COM_DATABIT_8  0x02            /* 8 data bits */

/* Parity flags (unsigned char) */
#define COM_PAR_NONE   0x00            /* no parity */
#define COM_PAR_EVEN   0x01            /* even parity */
#define COM_PAR_ODD    0x02            /* odd parity */

/* Detection enable flags (WORD_T) */
#define COM_DEN_NONE     0         /* no event detection enabled */
#define COM_DEN_MDM      0x0001    /* enable modem control change detection */
#define COM_DEN_RDA      0x0002    /* enable Rx data available detection */

/* Baud rate flags (unsigned char) */
#define COM_BAUD_50     0
#define COM_BAUD_75     0x1
#define COM_BAUD_110    0x2
#define COM_BAUD_134    0x3
#define COM_BAUD_150    0x4
#define COM_BAUD_200    0x5
#define COM_BAUD_300    0x6
#define COM_BAUD_600    0x7
#define COM_BAUD_1200   0x8
#define COM_BAUD_1800   0x9
#define COM_BAUD_2400   0xa
#define COM_BAUD_3600   0xb
#define COM_BAUD_4800   0xc
#define COM_BAUD_7200   0xd
#define COM_BAUD_9600   0xe
#define COM_BAUD_19200  0xf
#define COM_BAUD_38400  0x10
#define COM_BAUD_57600  0x11
#define COM_BAUD_76800  0x12
#define COM_BAUD_115200 0x13
#define COM_BAUD_230400 0x14

#define DEV_SIZE 128                 /* maximum number devices */


/* Error flags */
#define NO_ERR 0                 /* no errors */
#define ERR_NOCFGFILE 0x0100     /* aaInit() can't read configuration file */
#define ERR_ALLOCDEV  0x0200     /* aaInit() can't allocate device structure */
#define ERR_CTLINIT   0x0300     /* aaInit() controller initialization error */
#define ERR_CHANINIT  0x0400     /* aaInit() channel initialization error */
#define ERR_DEVSIZE   0x0500     /* aaInit() invalid number of devices */
#define ERR_CTLSIZE   0x0600     /* aaInit() invalid number of controllers */
#define ERR_NOINT     0x0700     /* aaInit() interrupts not occuring */
#define ERR_DEV            -1    /* device number out of range */
#define ERR_NOCTL          -1    /* no controller exists */
#define ERR_OPENTYPE       -2    /* invalid open type flag */
#define ERR_BAUDRATE       -3    /* invalid baud rate flag */
#define ERR_PAR            -4    /* invalid parity flag */
#define ERR_DATAB          -5    /* invalid data bits flag */
#define ERR_STOPB          -6    /* invalid stop bits flag */
#define ERR_FLOW           -7    /* invalid flow control flag */
#define ERR_DETECT         -8    /* invalid detect enable flag */
#define ERR_MDMCTL         -9    /* invalid modem control flag */
#define ERR_ALREADYOPEN   -10    /* device already open error flag */
#define ERR_NOTOPEN       -11    /* device not open error */
#define ERR_RX            -12    /* read error flag, indicates framing, parity,
                                    receiver overrun, or break occurred */
#define ERR_PARITY 0x01          /* parity error */
#define ERR_OVRRUN 0x02          /* receiver over run error */
#define ERR_FRAME  0x04          /* framing error */
#define ERR_BREAK  0x08          /* break (treated as Rx error condition) */

//--------------- following added for PCI support
#define MAX_PCI_BRDS  4
typedef struct  DevInfo {
	WORD_T   DevId ;          /* DeviceId */
	WORD_T   Base_Addr;       /* base io address for the board */
   WORD_T   id;              /* device id */
   WORD_T   num_ports;
	unsigned char   Irq;             /* int line assigned to board */
	unsigned char   Bus_num;         /* pci bus num where board is located */
	unsigned char   Dev_num;         /* boards device number on pci bus */
	unsigned char   Fctn_num;        /* boards function number */
} DEVINFO;

/* Function prototypes */
int aaAutoConfig(int allow_pci, int irq);
int aaFindPCIBoards(DEVINFO *DeviceInfoArray, int *NumDevs);
int aaSetConfig(int irq, unsigned int io1, unsigned int ports1,
                         unsigned int io2, unsigned int ports2,
                         unsigned int io3, unsigned int ports3,
                         unsigned int io4, unsigned int ports4);
int aaReadConfig(void);
WORD_T aaInit(void);
void aaInstallCtrlCHandler(void);
int aaGetCtlStatus(int CtlNum,int *FirstDevP,int *NumDevP);
int aaOpen(int Dev,WORD_T OpenType,unsigned long Baud,
                 unsigned char Parity,unsigned char DataBits,
                 unsigned char StopBits, WORD_T FlowCtl,
                 WORD_T DetectEn, unsigned char ModemCtl);
int aaReconfigure(int Dev,unsigned long Baud,unsigned char Parity,
                        unsigned char DataBits,unsigned char StopBits,
                        WORD_T FlowCtl,WORD_T DetectEn);
int aaSetBaud(int Dev, unsigned long BaudRate);
int aaClose(int Dev,unsigned char ModemCtl);
int aaSetCloseDelay(int Dev,int MaxDelay);
unsigned char aaGetModemStatus(int Dev);
int aaWrite(int Dev,int Cnt,unsigned char *Buf);
int aaRead(int Dev,int Cnt,unsigned char *Buf);
int aaReadWithStatus(int Dev,int Cnt,WORD_T *Buf);
int aaGetRxCount(int Dev);
int aaGetRxStatus(int Dev);
int aaGetRxStatusWord(int Dev);
int aaGetTxCount(int Dev);
int aaChangeModemState(int Dev,int RTSState,int DTRState);
int aaFlush(int Dev,unsigned char FlushFlags);
void aaExit(void);
int aaSendBreak(int Dev,int Time);
int aaCheckOpenType(WORD_T OpenType);
int aaCheckBaudRate(unsigned long Baud);
int aaCheckParity(unsigned char Parity);
int aaCheckDataB(unsigned char Datab);
int aaCheckStopB(unsigned char Stopb);
void aaInstallIrq(int Irq,void (interrupt far *IntHnd)());
void aaRestoreIrq(int Irq);
void interrupt far aaIntHandler(void);
void aaPollHandler(int tick_period);
void far aaCtrlCIntHandler(void);
void aaInstallMdmChgEvent(void (*EvFuncP)(int,unsigned char,unsigned char));
void aaInstallRxEvent(void (*EvFuncP)(int));
void aaInstallPeriodicEvent(void (*EvFuncP)(void));
void aaEnPeriodicEvent(int State);
void aaMdmChgEventNull(int Dev,unsigned char MdmChange,unsigned char MdmState);
void aaRxEventNull(int Dev);
void aaPeriodicEventNull(void);
void aaDelay(int Wait);

#ifdef __cplusplus
}
#endif
