/*---------------------------------------------------------------------------
File:    APIDAT.H
 Copyright 1993-96 Comtrol Corporation. All rights reserved.
|----------------------------------------------------------------------------*/

/***************************************************************************
   The following defines and prototypes are placed here instead of in
   API.H so that applications do not need to define BORLANDC or MSC, and so
   that they will be hidden from the user.
*/
void aaInstallIrq(int,void (interrupt far *)());

typedef struct                         /* Interrupt information structure */
{
   unsigned char Mask;                 /* mask value for 8259 mask register */
   WORD_T IntNum;
   WORD_T MaskIO;                /* I/O address of 8259 mask register */
} IRQ_T;

void interrupt far aaIntHandler(void);
void far aaCtrlCIntHandler(void);
void aaRestoreIrq(int);
void aaEnableInt(void);
void aaDisableInt(void);
void aaSetCarry(void);

#ifdef WATCOMC
#pragma aux aaEnableInt = "sti"
#pragma aux aaDisableInt = "cli"
#pragma aux aaSetCarry = "stc"
#endif

#if defined(BORLANDC) || defined(MSC)
#define aaEnableInt() ASM sti
#define aaDisableInt() ASM cli
#define aaSetCarry() ASM stc
#endif

/* #define INTERNAL_ISFLOW */ /* use AIOP's internal input software flow ctl */

/***************************************************************************/


CF_T aaCfg;                             /* configuration file data */
DEV_T far *aaDevices[DEV_SIZE];         /* pointers to device structures */
int far aaCtlSize = CTL_SIZE;           /* number of supported controllers */
int far aaDevSize;                      /* number of supported devices */
IRQ_T far aaIrqInfo[] =                 /* IRQ information */
{
  {0xfe,0x8,0x21}, /* IRQ0 */
  {0xfd,0x9,0x21}, /* IRQ1 */
  {0xfb,0xa,0x21}, /* IRQ2 */
  {0xf7,0xb,0x21}, /* IRQ3 */
  {0xef,0xc,0x21}, /* IRQ4 */
  {0xdf,0xd,0x21}, /* IRQ5 */
  {0xbf,0xe,0x21}, /* IRQ6 */
  {0x7f,0xf,0x21}, /* IRQ7 */
  {0xfe,0x70,0xa1}, /* IRQ8 */
  {0xfd,0x71,0xa1}, /* IRQ9 */
  {0xfb,0x72,0xa1}, /* IRQ10 */
  {0xf7,0x73,0xa1}, /* IRQ11 */
  {0xef,0x74,0xa1}, /* IRQ12 */
  {0xdf,0x75,0xa1}, /* IRQ13 */
  {0xbf,0x76,0xa1}, /* IRQ14 */
  {0x7f,0x77,0xa1}  /* IRQ15 */
};
int aaIrqSave;                         /* IRQ number save */
void (interrupt far *aaVectorSave)(void);  /* IRQ line interrupt vector save */
unsigned char aaMaskSave;              /* 8259 mask save */
WORD_T far aaEndOfIntIO;         /* 8259 I/O address for EOI */
unsigned long aaControllerTime;        /* controller time in micro seconds */
int aaPeriodicEventOn;                 /* TRUE if periodic event enabled */



/*******************************************************************************
  Define simple arrays that aid in the error checking for the API
  Library function parameters.
*******************************************************************************/
#define MAXDEV DEV_SIZE - 1
#define MAXNUMOTS 3
#define MAXNUMBAUDS COM_BAUD_230400 + 1
#define MAXNUMPARITYS 3
#define MAXNUMDATABS 2
#define MAXNUMSTOPBS 2

static WORD_T aaOpenTypeCheck[MAXNUMOTS]={COM_TX, COM_RX, COM_TX | COM_RX};

static unsigned char aaParityCheck[MAXNUMPARITYS]={COM_PAR_NONE,COM_PAR_EVEN,COM_PAR_ODD};

static unsigned char aaDataBCheck[MAXNUMDATABS]={COM_DATABIT_7,COM_DATABIT_8};

static unsigned char aaStopBCheck[MAXNUMSTOPBS]={COM_STOPBIT_1,COM_STOPBIT_2};


#define FLOWCHECK  (COM_FLOW_NONE | COM_FLOW_IS | COM_FLOW_IH | \
                   COM_FLOW_OS | COM_FLOW_OH | COM_FLOW_OXANY)


#define DETECTCHECK  (COM_DEN_RDA | COM_DEN_MDM)

#define MDMCTLCHECK  (COM_MDM_DTR | COM_MDM_RTS)

/* Array of baud rate divisors */
unsigned long aaBaud[22] =
{
   50,
   75,
   110,
   134,
   150,
   200,
   300,
   600,
   1200,
   1800,
   2400,
   3600,
   4800,
   7200,
   9600,
   19200L,
   38400L,
   57600L,
   76800L,
   115200L,
   230400L,
   460800L};

/* Array for converting IndID reg modem change bits into COM_MDM_XXX flags */
unsigned char aaModemChg[8] =
{
   0,COM_MDM_DSR,COM_MDM_CTS,COM_MDM_DSR|COM_MDM_CTS,COM_MDM_CD,
   COM_MDM_CD|COM_MDM_DSR,COM_MDM_CD|COM_MDM_CTS,COM_MDM_CD|COM_MDM_CTS|COM_MDM_DSR
};

#define DELTA_CD  0x04        /* CD change interrupt */
#define DELTA_CTS 0x02        /* CTS change interrupt */
#define DELTA_DSR 0x01        /* DSR change interrupt */


//---  Define the event function pointers.
void (*aaMdmChgEventP)(int,unsigned char,unsigned char);
void (*aaRxEventP)(int);
void (*aaPeriodicEventP)(void);
