/******************************************************************************
File:      TERM.C
Project:   RocketPort DOS API
Purpose:   Sample program
Comments:  This program is a simple terminal emulator that shows how to use
           the API to:
              Initialize the API
              Open a serial device
              Write to a serial device
              Read from a serial device
              Close a serial device
              Exit from the application program
Operation: At the DOS command line type <TERM>.  When prompted enter the
           device number of the serial port to be used.  The terminal emulator
           screen will then be displayed.  Characters typed on the keyboard
           will be transmitted out the port, and characters received from
           the port will be displayed on the screen.

           You can easily test that a port is operational by plugging a
           loopback plug into the serial port.  Then run TERM.  All
           characters typed on the keyboard will be transmitted out the
           port and then looped back into the port, so that each typed
           character will be displayed on the screen.
*******************************************************************************/

#include <stdio.h>
#include <dos.h>
#include <process.h>
#include <stdlib.h>
#include <conio.h>
#include "api.h"

main(void)
{
   unsigned short InitReturn;
   char Buf[80];
   int i,Dev,Cnt,Err;

   /* Initialize API */
   if (getenv("ROCKETCFG") == NULL)
   {
#ifdef WATCOMC
     printf("Config file not setup, run install.exe\n");
     exit(1);
#else
     printf("Auto-detecting RocketPort configuration...\n");
     aaAutoConfig(1, 0);  // setup 1 board at io-addr 180H, IRQ10
#endif
   }

   aaInstallCtrlCHandler();

   InitReturn = aaInit();
   if (InitReturn != NO_ERR)
   {
     printf("Init fail: %x\n",InitReturn);
     aaExit();
     exit(1);
   }

   /* Get serial device and display terminal emulator screen */
   printf("Serial Device Number(0=first port): ");
   gets(Buf);                                      /* get serial line */
   sscanf(Buf,"%d",&Dev);
   system("cls");                                  /* clear screen */
   printf("Serial Device Number %d\t\t\tHit F10 to Quit\n",Dev);

   /* Open the device */
   if((Err = aaOpen(Dev,
                    COM_TX | COM_RX,
                    COM_BAUD_9600,
                    COM_PAR_NONE,
                    COM_DATABIT_8,
                    COM_STOPBIT_1,
                    COM_FLOW_NONE,
                    COM_DEN_NONE,
                    COM_MDM_DTR)) != 0)
   {
      printf("Failure - Could not open device number %d, Error %d\n",Dev,Err);
      aaExit();                          /* required API call before exiting */
      exit(1);
   }

   /* Infinite loop to handle console I/O and serial I/O */
   while(1)
   {
      /* Attempt to read char from serial device and write to screen */
      if((Cnt = aaRead(Dev,80,(unsigned char *)Buf)) > 0)
      {
         for(i = 0;i < Cnt;i++)
            putch(Buf[i]);
      }

      /* Attempt to read char from keyboard and write to serial device */
      if((bdos(11,0,0) & 0xff) == 0xFF) /* if char waiting */
      {
         Buf[0] = bdos(8,0,0) & 0xff;   /* read keybd char */
         if((Buf[0] == '\0') && ((bdos(11,0,0)&0xff) == 0xff)) /* 2 char key */
         {
            Buf[1] = bdos(8,0,0) & 0xff; /* 2nd key */
               if(Buf[1] == 0x44)        /* F10 = quit */
                  break;
         }
         aaWrite(Dev,1,(unsigned char *)Buf); /* write char to serial device */
      }
   }

   aaClose(Dev,COM_MDM_RTS | COM_MDM_DTR); /* close device */
   aaExit();                             /* required API call before exiting */
   return(0);
}

